changeset 44155:d94cb7b3b165

(Fdisplay_buffer): Doc fix.
author Richard M. Stallman <rms@gnu.org>
date Tue, 26 Mar 2002 09:09:56 +0000
parents 879ec5292ef0
children b135f9d8d993
files src/window.c
diffstat 1 files changed, 2 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/src/window.c	Tue Mar 26 08:48:51 2002 +0000
+++ b/src/window.c	Tue Mar 26 09:09:56 2002 +0000
@@ -2898,7 +2898,7 @@
 argument NOT-THIS-WINDOW is non-nil (interactively, with prefix arg).
 If `pop-up-frames' is non-nil, make a new frame if no window shows BUFFER.
 Returns the window displaying BUFFER.
-If `display-reuse-frames' is non-nil, and another frame is currently
+If `display-buffer-reuse-frames' is non-nil, and another frame is currently
 displaying BUFFER, then simply raise that frame.
 
 The variables `special-display-buffer-names', `special-display-regexps',
@@ -2946,7 +2946,7 @@
 	}
     }
 
   /* If the user wants pop-up-frames or display-reuse-frames, then
      look for a window showing BUFFER on any visible or iconified frame.
      Otherwise search only the current frame.  */
   if (! NILP (frame))
@@ -2946,7 +2946,7 @@
     }
 
-  /* If the user wants pop-up-frames or display-reuse-frames, then
+  /* If the user wants pop-up-frames or display-buffer-reuse-frames,
      look for a window showing BUFFER on any visible or iconified frame.
      Otherwise search only the current frame.  */